@@ -24,33 +24,33 @@
 */
 
 #ifdef HAVE_CONFIG_H
-#include "../src/conf.h"
+# include "../src/conf.h"
 #endif
 
 #include <errno.h>
 
 #ifdef HAVE_DIRENT_H
-#include <dirent.h>
+# include <dirent.h>
 #endif
 
 #if !HAVE_DECL_DIRFD
 int dirfd(DIR *dirp);
 #endif
 
-/* Under Solaris dirfd(3) is just looking inside structure */
+/* Under Solaris, HP-UX and AIX dirfd(3) is just looking inside DIR structure */
 
 #if defined(__sun)
 
 int dirfd(DIR *dirp)
 {
-return dirp->d_fd != -1 ? dirp->d_fd : ENOTSUP;
+    return dirp->d_fd != -1 ? dirp->d_fd : ENOTSUP;
 }
 
-#endif
+#elif defined(__hpux) || defined(_AIX)
 
-#if defined(__hpux) || defined(_AIX)
 int dirfd(DIR *dirp)
 {
-return dirp->dd_fd != -1 ? dirp->dd_fd : ENOTSUP;
+    return dirp->dd_fd != -1 ? dirp->dd_fd : ENOTSUP;
 }
+
 #endif
