@@ -16,13 +16,23 @@
  * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
+#ifdef HAVE_CONFIG_H
+# include "../src/conf.h"
+#endif
+
 #include <sys/types.h>
 
 #include <stddef.h>
 #include <stdlib.h>
 #include <string.h>
 
+#if !HAVE_DECL_STRNLEN
+size_t strnlen(const char *str, size_t maxlen);
+#endif
+
+#if !HAVE_DECL_STRNDUP
 char *strndup(const char *str, size_t n);
+#endif
 
 char *
 strndup(const char *str, size_t maxlen)
