@@ -25,9 +25,7 @@
 #ifndef CFENGINE_BOOL_H
 #define CFENGINE_BOOL_H
 
-#ifdef HAVE_CONFIG_H
-# include "conf.h"
-#endif
+#include "platform.h"
 
 #ifdef HAVE_STDBOOL_H
 # include <stdbool.h>
