@@ -30,96 +30,83 @@
 /*******************************************************************/
 
 #include "cf3.defs.h"
-#include "cf3.extern.h"
 
 /*******************************************************************/
 
-int FixCompressedArrayValue(int i,char *value,struct CompressedArray **start)
-
-{ struct CompressedArray *ap;
-  char *sp;
-
-for (ap = *start; ap != NULL; ap = ap->next)
-   {
-   if (ap->key == i) 
-      {
-      /* value already fixed */
-      return false;
-      }
-   }
-
-Debug("FixCompressedArrayValue(%d,%s)\n",i,value);
-
-if ((ap = (struct CompressedArray *)malloc(sizeof(struct CompressedArray))) == NULL)
-   {
-   FatalError("Memory allocation in FixCompressedArray");
-   }
-
-if ((sp = malloc(strlen(value)+2)) == NULL)
-   {
-   FatalError("Memory allocation in FixCompressedArray");
-   }
-
-strcpy(sp,value);
-ap->key = i;
-ap->value = sp;
-ap->next = *start;
-*start = ap;
-return true;
-}
-
-
-/*******************************************************************/
-
-void DeleteCompressedArray(struct CompressedArray *start)
-
+int FixCompressedArrayValue(int i, char *value, CompressedArray **start)
 {
-if (start != NULL)
-   {
-   DeleteCompressedArray(start->next);
-   start->next = NULL;
+    CompressedArray *ap;
 
-   if (start->value != NULL)
-      {
-      free(start->value);
-      }
+    for (ap = *start; ap != NULL; ap = ap->next)
+    {
+        if (ap->key == i)
+        {
+            /* value already fixed */
+            return false;
+        }
+    }
 
-   free(start);
-   }
+    CfDebug("FixCompressedArrayValue(%d,%s)\n", i, value);
+
+    ap = xmalloc(sizeof(CompressedArray));
+
+    ap->key = i;
+    ap->value = xstrdup(value);
+    ap->next = *start;
+    *start = ap;
+    return true;
 }
 
 /*******************************************************************/
 
-int CompressedArrayElementExists(struct CompressedArray *start,int key)
+void DeleteCompressedArray(CompressedArray *start)
+{
+    if (start != NULL)
+    {
+        DeleteCompressedArray(start->next);
+        start->next = NULL;
 
-{ struct CompressedArray *ap;
+        if (start->value != NULL)
+        {
+            free(start->value);
+        }
 
-Debug("CompressedArrayElementExists(%d)\n",key);
-
-for (ap = start; ap !=NULL; ap = ap->next)
-   {
-   if (ap->key == key)
-      {
-      return true;
-      }
-   }
-
-return false;
+        free(start);
+    }
 }
 
 /*******************************************************************/
 
-char *CompressedArrayValue(struct CompressedArray *start,int key)
+int CompressedArrayElementExists(CompressedArray *start, int key)
+{
+    CompressedArray *ap;
 
-{ struct CompressedArray *ap;
+    CfDebug("CompressedArrayElementExists(%d)\n", key);
 
-for (ap = start; ap != NULL; ap = ap->next)
-   {
-   if (ap->key == key)
-      {
-      return ap->value;
-      }
-   }
+    for (ap = start; ap != NULL; ap = ap->next)
+    {
+        if (ap->key == key)
+        {
+            return true;
+        }
+    }
 
-return NULL;
+    return false;
+}
+
+/*******************************************************************/
+
+char *CompressedArrayValue(CompressedArray *start, int key)
+{
+    CompressedArray *ap;
+
+    for (ap = start; ap != NULL; ap = ap->next)
+    {
+        if (ap->key == key)
+        {
+            return ap->value;
+        }
+    }
+
+    return NULL;
 }
