@@ -33,4 +33,23 @@
 # define FUNC_ATTR_NORETURN
 #endif
 
+#if defined(__GNUC__)
+# if defined (__MINGW32__)
+#  define FUNC_ATTR_PRINTF(string_index, first_to_check) \
+    __attribute__((format(gnu_printf, string_index, first_to_check)))
+# else
+#  define FUNC_ATTR_PRINTF(string_index, first_to_check) \
+    __attribute__((format(printf, string_index, first_to_check)))
+# endif
+#else
+# define FUNC_ATTR_PRINTF(string_index, first_to_check)
+#endif
+
+#if defined(__GNUC__)
+#  define FUNC_DEPRECATED \
+    __attribute__((deprecated))
+#else
+#  define FUNC_DEPRECATED(warning_text)
+#endif
+
 #endif
