@@ -23,61 +23,37 @@
 
 */
 
-/*****************************************************************************/
-/*                                                                           */
-/* File: dtypes.c                                                            */
-/*                                                                           */
-/*****************************************************************************/
-
 #include "cf3.defs.h"
-#include "cf3.extern.h"
-
-static int IsProcessType(char *s);
-
-/*****************************************************************/
 
 int IsSocketType(char *s)
+{
+    int i;
 
-{ int i;
+    for (i = 0; i < ATTR; i++)
+    {
+        if (strstr(s, ECGSOCKS[i].name))
+        {
+            CfDebug("IsSocketType(%s=%s)\n", s, ECGSOCKS[i].name);
 
-for (i = 0; i < ATTR; i++)
-   {
-   if (strstr(s,ECGSOCKS[i].name))
-      {
-      Debug("IsSocketType(%s=%s)\n",s,ECGSOCKS[i].name);
-      
-      return true;
-      }
-   }
-return false;
+            return true;
+        }
+    }
+    return false;
 }
 
 /*****************************************************************/
 
 int IsTCPType(char *s)
-
-{ int i;
-
-for (i = 0; i < CF_NETATTR; i++)
-   {
-   if (strstr(s,TCPNAMES[i]))
-      {
-      Debug("IsTCPType(%s)\n",s); 
-      return true;
-      }
-   }
-return false;
-}
-
-/*****************************************************************/
-
-static int IsProcessType(char *s)
-
 {
- if (strcmp(s,"procs") == 0)
+    int i;
+
+    for (i = 0; i < CF_NETATTR; i++)
     {
-    return true;
+        if (strstr(s, TCPNAMES[i]))
+        {
+            CfDebug("IsTCPType(%s)\n", s);
+            return true;
+        }
     }
- 
- return false;
+    return false;
 }
