@@ -1,12 +1,10 @@
-#include <test.h>
-
-#include <alloc.h>
+#include "cf3.defs.h"
 
 #include <setjmp.h>
 #include <cmockery.h>
 #include <stdarg.h>
 
-void test_xasprintf(void)
+void test_xasprintf(void **p)
 {
     char *s;
     int res = xasprintf(&s, "Foo%d%s", 123, "17");
@@ -30,16 +28,15 @@ void test_xvasprintf_sub(const char *fmt, ...)
     free(s);
 }
 
-void test_xvasprintf(void)
+void test_xvasprintf(void **p)
 {
     test_xvasprintf_sub("Foo%d%s", 123, "17");
 }
 
 int main()
 {
-    PRINT_TEST_BANNER();
     const UnitTest tests[] =
-    {
+{
         unit_test(test_xasprintf),
         unit_test(test_xvasprintf),
     };
