@@ -18,7 +18,7 @@
 /* LCOV_EXCL_START */
 
 #ifdef HAVE_CONFIG_H
-# include <config.h>
+# include "config.h"
 #endif
 #ifdef HAVE_MALLOC_H
 # include <malloc.h>
@@ -40,7 +40,11 @@
 #endif // _WIN32
 #include <assert.h>
 #include <cmockery.h>
-#include <schema.h>
+#include "schema.h"
+
+#ifdef _WIN32
+# define vsnprintf _vsnprintf
+#endif // _WIN32
 
 /* Backwards compatibility with headers shipped with Visual Studio 2005 and
  * earlier. */
@@ -187,10 +191,10 @@ static int check_for_leftover_values(const ListNode *const map_head, const char
                                      const size_t number_of_symbol_names);
 // This must be called at the beginning of a test to initialize some data
 // structures.
-static void initialize_testing(void);
+static void initialize_testing(const char *test_name);
 
 // This must be called at the end of a test to free() allocated structures.
-static void teardown_testing(void);
+static void teardown_testing(const char *test_name);
 
 // Keeps track of the calling context returned by setenv() so that the fail()
 // method can jump out of a test.
@@ -222,9 +226,11 @@ static ListNode global_allocated_blocks;
 
 // Data of running tests for XML output.
 static int global_errors;
-static const char *global_filename;
-static const char *global_xmlfile;
-static int global_is_file_writer_test; /* bool, but type not defined here */
+const char *global_casename;
+const char *global_filename;
+const char *global_path;
+const char *global_suitename;
+const char *global_xmlfile;
 
 #ifndef _WIN32
 // Signals caught by exception_handler().
@@ -330,7 +336,7 @@ static void set_source_location(SourceLocation *const location, const char *cons
 }
 
 // Create function results and expected parameter lists.
-void initialize_testing(void)
+void initialize_testing(const char *test_name)
 {
     list_initialize(&global_function_result_map_head);
     initialize_source_location(&global_last_mock_value_location);
@@ -369,7 +375,7 @@ static void fail_if_leftover_values(const char *test_name)
     }
 }
 
-void teardown_testing(void)
+void teardown_testing(const char *test_name)
 {
     list_free(&global_function_result_map_head, free_symbol_map_value, (void *) 0);
     initialize_source_location(&global_last_mock_value_location);
@@ -489,14 +495,8 @@ static int list_first(ListNode *const head, ListNode **output)
     return 1;
 }
 
-#if defined(__GNUC__) && ((__GNUC__ * 100 +  __GNUC_MINOR__ * 10) >= 240)
-# define ARG_UNUSED __attribute__((unused))
-#else
-# define ARG_UNUSED
-#endif
-
 // Deallocate a value referenced by a list.
-static void free_value(const void *value, ARG_UNUSED void *cleanup_value_data)
+static void free_value(const void *value, void *cleanup_value_data)
 {
     assert_true(value);
     free((void *) value);
@@ -873,11 +873,10 @@ static int value_in_set_display_error(const LargestIntegralType value,
         {
             return 1;
         }
-        print_error(LargestIntegralTypePrintfDecimal " is %sin the set (",
-                    value, invert ? "" : "not ");
+        print_error("%d is %sin the set (", value, invert ? "" : "not ");
         for (i = 0; i < size_of_set; i++)
         {
-            print_error(LargestIntegralTypePrintfDecimal ", ", set[i]);
+            print_error("%d, ", set[i]);
         }
         print_error(")\n");
     }
@@ -894,9 +893,7 @@ static int integer_in_range_display_error(const LargestIntegralType value, const
     {
         return 1;
     }
-    print_error(LargestIntegralTypePrintfDecimal " is not within the range "
-                LargestIntegralTypePrintfDecimal "-" LargestIntegralTypePrintfDecimal "\n",
-                value, range_min, range_max);
+    print_error("%d is not within the range %d-%d\n", value, range_min, range_max);
     return 0;
 }
 
@@ -910,9 +907,7 @@ static int integer_not_in_range_display_error(const LargestIntegralType value, c
     {
         return 1;
     }
-    print_error(LargestIntegralTypePrintfDecimal " is within the range "
-                LargestIntegralTypePrintfDecimal "-" LargestIntegralTypePrintfDecimal "\n",
-                value, range_min, range_max);
+    print_error("%d is within the range %d-%d\n", value, range_min, range_max);
     return 0;
 }
 
@@ -1211,7 +1206,7 @@ void _expect_not_memory(const char *const function, const char *const parameter,
 }
 
 // CheckParameterValue callback that always returns 1.
-static int check_any(ARG_UNUSED const LargestIntegralType value, ARG_UNUSED const LargestIntegralType check_value_data)
+static int check_any(const LargestIntegralType value, const LargestIntegralType check_value_data)
 {
     return 1;
 }
@@ -1679,8 +1674,10 @@ static LONG WINAPI exception_filter(EXCEPTION_POINTERS *exception_pointers)
 
 void vinit_xml (const char *const format, va_list args)
 {
+    char buffer[1024] = {0};
     FILE* xmlfile = fopen(global_xmlfile, "w");
-    vfprintf(xmlfile, format, args);
+    vsnprintf(buffer, sizeof(buffer), format, args);
+    fprintf(xmlfile, "%s", buffer);
     fclose(xmlfile);
 #ifdef _WIN32
     OutputDebugString(buffer);
@@ -1689,7 +1686,7 @@ void vinit_xml (const char *const format, va_list args)
 
 void init_xml (const char *const format, ...)
 {
-    if (!global_is_file_writer_test)
+    if(strcmp(global_suitename, "file_writer_test") != 0)
     {
         va_list args;
         va_start(args, format);
@@ -1700,8 +1697,10 @@ void init_xml (const char *const format, ...)
 
 void vprint_xml(const char *const format, va_list args)
 {
+    char buffer[1024] = {0};
     FILE* xmlfile = fopen(global_xmlfile, "a");
-    vfprintf(xmlfile, format, args);
+    vsnprintf(buffer, sizeof(buffer), format, args);
+    fprintf(xmlfile, "%s", buffer);
     fclose(xmlfile);
 #ifdef _WIN32
     OutputDebugString(buffer);
@@ -1710,7 +1709,7 @@ void vprint_xml(const char *const format, va_list args)
 
 void print_xml(const char *const format, ...)
 {
-    if (!global_is_file_writer_test)
+    if(strcmp(global_suitename, "file_writer_test") != 0)
     {
         va_list args;
         va_start(args, format);
@@ -1721,7 +1720,7 @@ void print_xml(const char *const format, ...)
 
 void append_xml(const char *ofile, const char *ifile)
 {
-    if (!global_is_file_writer_test)
+    if(strcmp(global_suitename, "file_writer_test") != 0)
     {
         char ch;
         FILE* xmlfile = fopen(ofile, "ab");
@@ -1742,7 +1741,10 @@ void append_xml(const char *ofile, const char *ifile)
 // Standard output and error print methods.
 void vprint_message(const char *const format, va_list args)
 {
-    vprintf(format, args);
+    char buffer[1024];
+
+    vsnprintf(buffer, sizeof(buffer), format, args);
+    printf("%s", buffer);
 #ifdef _WIN32
     OutputDebugString(buffer);
 #endif // _WIN32
@@ -1750,7 +1752,10 @@ void vprint_message(const char *const format, va_list args)
 
 void vprint_error(const char *const format, va_list args)
 {
-    vfprintf(stderr, format, args);
+    char buffer[1024];
+
+    vsnprintf(buffer, sizeof(buffer), format, args);
+    fprintf(stderr, "%s", buffer);
 #ifdef _WIN32
     OutputDebugString(buffer);
 #endif // _WIN32
@@ -1803,23 +1808,15 @@ int _run_test(const char *const function_name, const UnitTestFunction Function,
 #endif // !_WIN32
     }
 
-    if (function_type == UNIT_TEST_FUNCTION_TYPE_TEST || function_type == UNIT_TEST_FUNCTION_TYPE_TEST_WITH_STATE)
+    if (function_type == UNIT_TEST_FUNCTION_TYPE_TEST)
     {
         print_message("%s: Starting test\n", function_name);
     }
-    initialize_testing();
+    initialize_testing(function_name);
     global_running_test = 1;
     if (setjmp(global_run_test_env) == 0)
     {
-        if (function_type == UNIT_TEST_FUNCTION_TYPE_TEST)
-        {
-            Function();
-        }
-        else
-        {
-            ((UnitTestFunctionWithState)Function)(state ? state : &current_state);
-        }
-
+        Function(state ? state : &current_state);
         fail_if_leftover_values(function_name);
 
         /* If this is a setup function then ignore any allocated blocks
@@ -1831,7 +1828,7 @@ int _run_test(const char *const function_name, const UnitTestFunction Function,
 
         global_running_test = 0;
 
-        if (function_type == UNIT_TEST_FUNCTION_TYPE_TEST || function_type == UNIT_TEST_FUNCTION_TYPE_TEST_WITH_STATE)
+        if (function_type == UNIT_TEST_FUNCTION_TYPE_TEST)
         {
             print_message("%s: Test completed successfully.\n", function_name);
         }
@@ -1842,7 +1839,7 @@ int _run_test(const char *const function_name, const UnitTestFunction Function,
         global_running_test = 0;
         print_message("%s: Test failed.\n", function_name);
     }
-    teardown_testing();
+    teardown_testing(function_name);
 
     if (handle_exceptions)
     {
@@ -1920,7 +1917,7 @@ int _run_tests(const UnitTest *const tests, const size_t number_of_tests, const
     char xmlfile[1024]     = {0};
     int len;
 
-    strcpy(path, file);
+    sprintf(path, "%s", file);
     strcpy(filename, basename(path));
     len = strrchr(filename, '.')-filename;
 
@@ -1928,8 +1925,9 @@ int _run_tests(const UnitTest *const tests, const size_t number_of_tests, const
     strncat(suitename, filename, len);
     strcpy(xmlfile, "xml_tmp_suite");
 
+    global_path = path;
     global_filename = filename;
-    global_is_file_writer_test = (0 == strcmp(suitename, "file_writer_test"));
+    global_suitename = suitename;
     global_xmlfile = xmlfile;
     global_errors = 0;
 
@@ -1942,7 +1940,7 @@ int _run_tests(const UnitTest *const tests, const size_t number_of_tests, const
         TestState *current_TestState;
         const UnitTest *const test = &tests[current_test++];
 
-        if (!test->f.function)
+        if (!test->function)
         {
             continue;
         }
@@ -1950,7 +1948,6 @@ int _run_tests(const UnitTest *const tests, const size_t number_of_tests, const
         switch (test->function_type)
         {
         case UNIT_TEST_FUNCTION_TYPE_TEST:
-        case UNIT_TEST_FUNCTION_TYPE_TEST_WITH_STATE:
             run_next_test = 1;
             break;
         case UNIT_TEST_FUNCTION_TYPE_SETUP:
@@ -1988,9 +1985,10 @@ int _run_tests(const UnitTest *const tests, const size_t number_of_tests, const
         {
             strcpy(casename, test->name);
             strcpy(xmlfile, "xml_tmp_case");
+            global_casename = casename;
             init_xml("");
             time(&time_case);
-            int failed = _run_test(test->name, test->f.function, current_state,
+            int failed = _run_test(test->name, test->function, current_state,
                                    test->function_type, test_check_point);
             strcpy(xmlfile, "xml_tmp_suite");
             time(&time_now);
@@ -2004,7 +2002,6 @@ int _run_tests(const UnitTest *const tests, const size_t number_of_tests, const
             switch (test->function_type)
             {
             case UNIT_TEST_FUNCTION_TYPE_TEST:
-            case UNIT_TEST_FUNCTION_TYPE_TEST_WITH_STATE:
                 previous_test_failed = failed;
                 total_failed += failed;
                 tests_executed++;
@@ -2068,4 +2065,4 @@ int _run_tests(const UnitTest *const tests, const size_t number_of_tests, const
     return (int) total_failed;
 }
 
-/* LCOV_EXCL_STOP */
+/* LCOV_EXCL_STOP */
\ No newline at end of file
