@@ -48,10 +48,8 @@
 # ifndef LargestIntegralTypePrintfFormat
 #  ifdef _WIN32
 #   define LargestIntegralTypePrintfFormat "%I64x"
-#   define LargestIntegralTypePrintfDecimal "%I64d"
 #  else
 #   define LargestIntegralTypePrintfFormat "%llx"
-#   define LargestIntegralTypePrintfDecimal "%lld"
 #  endif
        // _WIN32
 # endif// LargestIntegralTypePrintfFormat
@@ -243,19 +241,18 @@
 # define run_test(f) _run_test(#f, f, NULL, UNIT_TEST_FUNCTION_TYPE_TEST, NULL)
 
 // Initializes a UnitTest structure.
-# define unit_test(func) { .name = #func, .f = { .function = func }, .function_type = UNIT_TEST_FUNCTION_TYPE_TEST }
-# define unit_test_with_state(func) { .name = #func, .f = { .function_with_state = func }, .function_type = UNIT_TEST_FUNCTION_TYPE_TEST_WITH_STATE }
+# define unit_test(f) { #f, f, UNIT_TEST_FUNCTION_TYPE_TEST }
 # define unit_test_setup(test, setup) \
-    { .name = #test "_" #setup, .f = { .function_with_state = setup }, .function_type = UNIT_TEST_FUNCTION_TYPE_SETUP }
+    { #test "_" #setup, setup, UNIT_TEST_FUNCTION_TYPE_SETUP }
 # define unit_test_teardown(test, teardown) \
-    { .name = #test "_" #teardown, .f = { .function_with_state = teardown }, .function_type = UNIT_TEST_FUNCTION_TYPE_TEARDOWN }
+    { #test "_" #teardown, teardown, UNIT_TEST_FUNCTION_TYPE_TEARDOWN }
 
 /* Initialize an array of UnitTest structures with a setup function for a test
  * and a teardown function.  Either setup or teardown can be NULL.
  */
 # define unit_test_setup_teardown(test, setup, teardown) \
     unit_test_setup(test, setup), \
-    unit_test_with_state(test), \
+    unit_test(test), \
     unit_test_teardown(test, teardown)
 
 /*
@@ -322,9 +319,7 @@
   }
 
 // Function prototype for setup, test and teardown functions.
-typedef void (*UnitTestFunction) (void);
-
-typedef void (*UnitTestFunctionWithState) (void **state);
+typedef void (*UnitTestFunction) (void **state);
 
 // Function that determines whether a function parameter value is correct.
 typedef int (*CheckParameterValue) (const LargestIntegralType value, const LargestIntegralType check_value_data);
@@ -333,7 +328,6 @@ typedef int (*CheckParameterValue) (const LargestIntegralType value, const Large
 typedef enum UnitTestFunctionType
 {
     UNIT_TEST_FUNCTION_TYPE_TEST = 0,
-    UNIT_TEST_FUNCTION_TYPE_TEST_WITH_STATE,
     UNIT_TEST_FUNCTION_TYPE_SETUP,
     UNIT_TEST_FUNCTION_TYPE_TEARDOWN,
 } UnitTestFunctionType;
@@ -345,11 +339,7 @@ typedef enum UnitTestFunctionType
 typedef struct UnitTest
 {
     const char *name;
-    union
-    {
-        UnitTestFunction function;
-        UnitTestFunctionWithState function_with_state;
-    } f;
+    UnitTestFunction function;
     UnitTestFunctionType function_type;
 } UnitTest;
 
