@@ -1,17 +1,10 @@
-#include <test.h>
+#include "cf3.defs.h"
+#include "dbm_api.h"
+#include "test.h"
+#include "lastseen.h"
 
-#include <cf3.defs.h>
-#include <dbm_api.h>
-#include <lastseen.h>
-#include <misc_lib.h>                                          /* xsnprintf */
-#include <known_dirs.h>
-
-#ifdef LMDB
-int main()
-{
-    return 0;
-}
-#else
+#include <setjmp.h>
+#include <cmockery.h>
 
 typedef struct
 {
@@ -25,16 +18,8 @@ char CFWORKDIR[CF_BUFSIZE];
 
 void tests_setup(void)
 {
-    static char env[] = /* Needs to be static for putenv() */
-        "CFENGINE_TEST_OVERRIDE_WORKDIR=/tmp/lastseen_migration_test.XXXXXX";
-
-    char *workdir = strchr(env, '=') + 1; /* start of the path */
-    assert(workdir - 1 && workdir[0] == '/');
-
-    mkdtemp(workdir);
-    strlcpy(CFWORKDIR, workdir, CF_BUFSIZE);
-    putenv(env);
-    mkdir(GetStateDir(), (S_IRWXU | S_IRWXG | S_IRWXO));
+    snprintf(CFWORKDIR, CF_BUFSIZE, "/tmp/lastseen_migration_test.XXXXXX");
+    mkdtemp(CFWORKDIR);
 }
 
 /*
@@ -43,7 +28,7 @@ void tests_setup(void)
 static DBHandle *setup(bool clean)
 {
     char cmd[CF_BUFSIZE];
-    xsnprintf(cmd, CF_BUFSIZE, "rm -rf '%s'/*", GetStateDir());
+    snprintf(cmd, CF_BUFSIZE, "rm -rf '%s'/*", CFWORKDIR);
     system(cmd);
 
     DBHandle *db;
@@ -64,12 +49,12 @@ static DBHandle *setup(bool clean)
         void *value;
         int ksize, vsize;
 
-        while (NextDB(cursor, &key, &ksize, &value, &vsize))
+        while (NextDB(db, cursor, &key, &ksize, &value, &vsize))
         {
             DBCursorDeleteEntry(cursor);
         }
 
-        if (!DeleteDBCursor(cursor))
+        if (!DeleteDBCursor(db, cursor))
         {
             return NULL;
         }
@@ -81,11 +66,11 @@ static DBHandle *setup(bool clean)
 static void tests_teardown(void)
 {
     char cmd[CF_BUFSIZE];
-    xsnprintf(cmd, CF_BUFSIZE, "rm -rf '%s'", CFWORKDIR);
+    snprintf(cmd, CF_BUFSIZE, "rm -rf '%s'", CFWORKDIR);
     system(cmd);
 }
 
-static void test_no_migration(void)
+static void test_no_migration(void **context)
 {
     DBHandle *db = setup(true);
 
@@ -102,7 +87,7 @@ static void test_no_migration(void)
     void *value;
     int ksize, vsize;
 
-    while (NextDB(cursor, &key, &ksize, &value, &vsize))
+    while (NextDB(db, cursor, &key, &ksize, &value, &vsize))
     {
         assert_int_equal(ksize, strlen("version") + 1);
         assert_string_equal(key, "version");
@@ -110,12 +95,12 @@ static void test_no_migration(void)
         assert_string_equal(value, "1");
     }
 
-    assert_int_equal(DeleteDBCursor(cursor), true);
+    assert_int_equal(DeleteDBCursor(db, cursor), true);
 
     CloseDB(db);
 }
 
-static void test_up_to_date(void)
+static void test_up_to_date(void **context)
 {
     /* Test that upgrade is not performed if there is already a version
      * marker */
@@ -199,17 +184,17 @@ void test_migrate_single(const char *expected_old_key,
     CloseDB(db);
 }
 
-void test_migrate_incoming(void)
+void test_migrate_incoming(void **context)
 {
     test_migrate_single(KEYHASH_IN, QUALITY_IN);
 }
 
-void test_migrate_outgoing(void)
+void test_migrate_outgoing(void **context)
 {
     test_migrate_single(KEYHASH_OUT, QUALITY_OUT);
 }
 
-void test_ignore_wrong_sized(void)
+void test_ignore_wrong_sized(void **context)
 {
     /* Test that malformed values are discarded */
 
@@ -252,35 +237,57 @@ int main()
 
 /* STUBS */
 
-void FatalError(ARG_UNUSED char *s, ...)
+void FatalError(char *s, ...)
 {
     fail();
     exit(42);
 }
 
-HashMethod CF_DEFAULT_DIGEST;
+void CfOut(enum cfreport level, const char *errstr, const char *fmt, ...)
+{
+    fprintf(stderr, "CFOUT<%d>: ", level);
+    if (errstr)
+    {
+        fprintf(stderr, " %s: %s ", errstr, strerror(errno));
+    }
+    va_list ap;
+    va_start(ap, fmt);
+    vfprintf(stderr, fmt, ap);
+    va_end(ap);
+    fprintf(stderr, "\n");
+}
+
+enum cfhashes CF_DEFAULT_DIGEST;
+const char *DAY_TEXT[] = {};
+const char *MONTH_TEXT[] = {};
+const char *SHIFT_TEXT[] = {};
 pthread_mutex_t *cft_output;
-char VIPADDRESS[CF_MAX_IP_LEN];
+char VIPADDRESS[18];
 RSA *PUBKEY;
-bool MINUSF;
+int DEBUG;
+int MINUSF;
 
-char *MapAddress(ARG_UNUSED char *addr)
+char *MapAddress(char *addr)
 {
     fail();
 }
 
-char *HashPrintSafe(ARG_UNUSED char *dst, ARG_UNUSED size_t dst_size,
-                    ARG_UNUSED const unsigned char *digest,
-                    ARG_UNUSED HashMethod type, ARG_UNUSED bool use_prefix)
+char *HashPrint(enum cfhashes type, unsigned char digest[EVP_MAX_MD_SIZE + 1])
 {
     fail();
 }
 
-void HashPubKey(ARG_UNUSED const RSA *key,
-                ARG_UNUSED unsigned char digest[EVP_MAX_MD_SIZE + 1],
-                ARG_UNUSED HashMethod type)
+int ThreadLock(pthread_mutex_t *name)
 {
     fail();
 }
 
-#endif // LMDB
+int ThreadUnlock(pthread_mutex_t *name)
+{
+    fail();
+}
+
+void HashPubKey(RSA *key, unsigned char digest[EVP_MAX_MD_SIZE + 1], enum cfhashes type)
+{
+    fail();
+}
