@@ -1,22 +1,22 @@
-#include <test.h>
+#include "cf3.defs.h"
+#include "sort.h"
 
-#include <cf3.defs.h>
-#include <sort.h>
-#include <rlist.h>
-#include <item_lib.h>
+#include <setjmp.h>
+#include <cmockery.h>
+#include <stdarg.h>
 
 /*
  * Those testcases only perform smoke testing of sorting functionality.
  */
 
-void test_sort_item_list_names(void)
+void test_sort_item_list_names(void **ctx)
 {
     Item *head = xcalloc(1, sizeof(Item));
-    head->name = xstrdup("c");
+    head->name = "c";
     head->next = xcalloc(1, sizeof(Item));
-    head->next->name = xstrdup("b");
+    head->next->name = "b";
     head->next->next = xcalloc(1, sizeof(Item));
-    head->next->next->name = xstrdup("a");
+    head->next->next->name = "a";
 
     Item *sorted = SortItemListNames(head);
 
@@ -24,18 +24,16 @@ void test_sort_item_list_names(void)
     assert_string_equal(sorted->next->name, "b");
     assert_string_equal(sorted->next->next->name, "c");
     assert_int_equal(sorted->next->next->next, NULL);
-
-    DeleteItemList(sorted);
 }
 
-void test_sort_item_list_classes(void)
+void test_sort_item_list_classes(void **ctx)
 {
     Item *head = xcalloc(1, sizeof(Item));
-    head->classes = xstrdup("b");
+    head->classes = "b";
     head->next = xcalloc(1, sizeof(Item));
-    head->next->classes = xstrdup("c");
+    head->next->classes = "c";
     head->next->next = xcalloc(1, sizeof(Item));
-    head->next->next->classes = xstrdup("a");
+    head->next->next->classes = "a";
 
     Item *sorted = SortItemListClasses(head);
 
@@ -43,11 +41,9 @@ void test_sort_item_list_classes(void)
     assert_string_equal(sorted->next->classes, "b");
     assert_string_equal(sorted->next->next->classes, "c");
     assert_int_equal(sorted->next->next->next, NULL);
-
-    DeleteItemList(sorted);
 }
 
-void test_sort_item_list_counters(void)
+void test_sort_item_list_counters(void **ctx)
 {
     Item *head = xcalloc(1, sizeof(Item));
     head->counter = -1;
@@ -63,11 +59,9 @@ void test_sort_item_list_counters(void)
     assert_int_equal(sorted->next->counter, 42);
     assert_int_equal(sorted->next->next->counter, -1);
     assert_int_equal(sorted->next->next->next, NULL);
-
-    DeleteItemList(sorted);
 }
 
-void test_sort_item_list_times(void)
+void test_sort_item_list_times(void **ctx)
 {
     Item *head = xcalloc(1, sizeof(Item));
     head->time = 1;
@@ -82,8 +76,6 @@ void test_sort_item_list_times(void)
     assert_int_equal(sorted->next->time, 1998);
     assert_int_equal(sorted->next->next->time, 1);
     assert_int_equal(sorted->next->next->next, NULL);
-
-    DeleteItemList(sorted);
 }
 
 int FirstItemShorter(const char *lhs, const char *rhs)
@@ -91,68 +83,60 @@ int FirstItemShorter(const char *lhs, const char *rhs)
     return strlen(lhs) < strlen(rhs);
 }
 
-void test_sort_rlist(void)
+void test_sort_rlist(void **ctx)
 {
-    Rlist *list = NULL;
-    RlistAppendScalar(&list, "bbb");
-    RlistAppendScalar(&list, "cc");
-    RlistAppendScalar(&list, "a");
+    Rlist *head = xcalloc(1, sizeof(Rlist));
+    head->item = "a";
+    head->next = xcalloc(1, sizeof(Rlist));
+    head->next->item = "bbb";
+    head->next->next = xcalloc(1, sizeof(Rlist));
+    head->next->next->item = "cc";
 
-    Rlist *sorted = SortRlist(list, &FirstItemShorter);
+    Rlist *sorted = SortRlist(head, &FirstItemShorter);
 
-    assert_string_equal(RlistScalarValue(sorted), "a");
-    assert_string_equal(RlistScalarValue(sorted->next), "cc");
-    assert_string_equal(RlistScalarValue(sorted->next->next), "bbb");
+    assert_string_equal(sorted->item, "a");
+    assert_string_equal(sorted->next->item, "cc");
+    assert_string_equal(sorted->next->next->item, "bbb");
     assert_int_equal(sorted->next->next->next, NULL);
-
-    RlistDestroy(sorted);
 }
 
-void test_alpha_sort_rlist_names(void)
+void test_alpha_sort_rlist_names(void **ctx)
 {
-    Rlist *list = NULL;
-    RlistAppendScalar(&list, "c");
-    RlistAppendScalar(&list, "a");
-    RlistAppendScalar(&list, "b");
+    Rlist *head = xcalloc(1, sizeof(Rlist));
+    head->item = "c";
+    head->next = xcalloc(1, sizeof(Rlist));
+    head->next->item = "a";
+    head->next->next = xcalloc(1, sizeof(Rlist));
+    head->next->next->item = "b";
 
-    Rlist *sorted = AlphaSortRListNames(list);
+    Rlist *sorted = AlphaSortRListNames(head);
 
-    assert_string_equal(RlistScalarValue(sorted), "a");
-    assert_string_equal(RlistScalarValue(sorted->next), "b");
-    assert_string_equal(RlistScalarValue(sorted->next->next), "c");
+    assert_string_equal(sorted->item, "a");
+    assert_string_equal(sorted->next->item, "b");
+    assert_string_equal(sorted->next->next->item, "c");
     assert_int_equal(sorted->next->next->next, NULL);
-
-    RlistDestroy(sorted);
 }
 
 int main()
 {
-    PRINT_TEST_BANNER();
     const UnitTest tests[] =
-    {
-        unit_test(test_sort_item_list_names),
-        unit_test(test_sort_item_list_classes),
-        unit_test(test_sort_item_list_counters),
-        unit_test(test_sort_item_list_times),
-        unit_test(test_sort_rlist),
-        unit_test(test_alpha_sort_rlist_names),
-    };
+        {
+            unit_test(test_sort_item_list_names),
+            unit_test(test_sort_item_list_classes),
+            unit_test(test_sort_item_list_counters),
+            unit_test(test_sort_item_list_times),
+            unit_test(test_sort_rlist),
+            unit_test(test_alpha_sort_rlist_names),
+        };
 
     return run_tests(tests);
 }
 
 /* STUBS */
 
-/*
-void __ProgrammingError(const char *file, int lineno, const char *format, ...)
-{
-    fail();
-    exit(42);
-}
-
 void FatalError(char *s, ...)
 {
     fail();
     exit(42);
 }
-*/
+
