@@ -1,9 +1,8 @@
-#include <test.h>
-
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
-#include <alloc.h>
+#include "test.h"
+#include "alloc.h"
 
 char *file_read_string(FILE *in)
 {
@@ -53,13 +52,3 @@ void _assert_double_close(double left, double right, const char *const file, con
     }
 }
 
-void test_progress()
-{
-    putchar('.');
-    fflush(stdout);
-}
-void test_progress_end()
-{
-    putchar('\n');
-    fflush(stdout);
-}
